/**
 * @packageDocumentation
 * @module Components
 */
import React from 'react';
import { StyleProp, ViewStyle } from 'react-native';
/**
 * @param text  The text shown inside of the instruction
 * @param style  (Optional) Custom style to style the instruction.
 * @param hasBottomBorder  (Optional) Specify if the instruction should have a bottom border. Default true.
 */
declare type InstructionProps = {
    text: string;
    style?: StyleProp<ViewStyle>;
    hasBottomBorder?: boolean;
};
/**
 * Displays a block of text with a light grey underline beneath. This underline should extend to the edge of the screen,
 * so the props.style passed in will directly affect only the Text inside. Underline is visible by default, but can be
 * disabled by setting hasBottomBorder to false.
 *
 * @category Component
 */
export declare const Instruction: React.FC<InstructionProps>;
export {};
